==> aws-java-sdk-inspector-1.11.1-sources.jar: com/amazonaws/services/inspector/model/InvalidCrossAccountRoleErrorCode.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.inspector.model;

/**
 * 
 */
public enum InvalidCrossAccountRoleErrorCode {

    ROLE_DOES_NOT_EXIST_OR_INVALID_TRUST_RELATIONSHIP(
            "ROLE_DOES_NOT_EXIST_OR_INVALID_TRUST_RELATIONSHIP"),
    ROLE_DOES_NOT_HAVE_CORRECT_POLICY("ROLE_DOES_NOT_HAVE_CORRECT_POLICY");

    private String value;

    private InvalidCrossAccountRoleErrorCode(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *        real value
     * @return InvalidCrossAccountRoleErrorCode corresponding to the value
     */
    public static InvalidCrossAccountRoleErrorCode fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        } else if ("ROLE_DOES_NOT_EXIST_OR_INVALID_TRUST_RELATIONSHIP"
                .equals(value)) {
            return ROLE_DOES_NOT_EXIST_OR_INVALID_TRUST_RELATIONSHIP;
        } else if ("ROLE_DOES_NOT_HAVE_CORRECT_POLICY".equals(value)) {
            return ROLE_DOES_NOT_HAVE_CORRECT_POLICY;
        } else {
            throw new IllegalArgumentException("Cannot create enum from "
                    + value + " value!");
        }
    }
}

==> aws-java-sdk-inspector-1.11.7-sources.jar: com/amazonaws/services/inspector/model/InvalidCrossAccountRoleErrorCode.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.inspector.model;

/**
 * 
 */
public enum InvalidCrossAccountRoleErrorCode {

    ROLE_DOES_NOT_EXIST_OR_INVALID_TRUST_RELATIONSHIP(
            "ROLE_DOES_NOT_EXIST_OR_INVALID_TRUST_RELATIONSHIP"),
    ROLE_DOES_NOT_HAVE_CORRECT_POLICY("ROLE_DOES_NOT_HAVE_CORRECT_POLICY");

    private String value;

    private InvalidCrossAccountRoleErrorCode(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *        real value
     * @return InvalidCrossAccountRoleErrorCode corresponding to the value
     */
    public static InvalidCrossAccountRoleErrorCode fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        }

        for (InvalidCrossAccountRoleErrorCode enumEntry : InvalidCrossAccountRoleErrorCode
                .values()) {
            if (enumEntry.toString().equals(value)) {
                return enumEntry;
            }
        }

        throw new IllegalArgumentException("Cannot create enum from " + value
                + " value!");
    }
}
